@@ -1,7 +1,8 @@
 /*
+ * Copyright 2010 L. Vandenberghe.
  * Copyright 2004-2009 J. Dahl and L. Vandenberghe.
  *
- * This file is part of CVXOPT version 1.1.2
+ * This file is part of CVXOPT version 1.1.3.
  *
  * CVXOPT is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -844,6 +845,8 @@ matrix_ass_subscr(matrix* self, PyObject* args, PyObject* val)
         }
       }
 
+    if (decref_val) { Py_DECREF(val); }
+ 
     return 0;
   }
 
